summaryrefslogtreecommitdiffstats
path: root/chrome/browser/sync/engine/syncapi.cc
diff options
context:
space:
mode:
authortim@chromium.org <tim@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-10-16 01:31:55 +0000
committertim@chromium.org <tim@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-10-16 01:31:55 +0000
commit1b4ec9a088731d6cd028ffdf6695b0f5e2748846 (patch)
tree739d90bcbc8b5aa4c3d171d0e9d62ddb1c6c51a4 /chrome/browser/sync/engine/syncapi.cc
parent4f92fbc2765f3bd2db6d076c9b4d17410b847538 (diff)
downloadchromium_src-1b4ec9a088731d6cd028ffdf6695b0f5e2748846.zip
chromium_src-1b4ec9a088731d6cd028ffdf6695b0f5e2748846.tar.gz
chromium_src-1b4ec9a088731d6cd028ffdf6695b0f5e2748846.tar.bz2
Hook up ClientToServerResponse::THROTTLED to the client sync loop.
TEST=Added SyncerThreadWithSyncerTest.Throttling Review URL: http://codereview.chromium.org/269101 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@29236 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/sync/engine/syncapi.cc')
-rw-r--r--chrome/browser/sync/engine/syncapi.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/chrome/browser/sync/engine/syncapi.cc b/chrome/browser/sync/engine/syncapi.cc
index b0eaa5b..099f831 100644
--- a/chrome/browser/sync/engine/syncapi.cc
+++ b/chrome/browser/sync/engine/syncapi.cc
@@ -1395,11 +1395,11 @@ void SyncManager::SyncInternal::HandleSyncerEvent(const SyncerEvent& event) {
// Notifications are sent at the end of every sync cycle, regardless of
// whether we should sync again.
if (event.what_happened == SyncerEvent::SYNC_CYCLE_ENDED) {
- if (!event.last_session->ShouldSyncAgain()) {
+ if (!event.last_session->HasMoreToSync()) {
observer_->OnSyncCycleCompleted();
}
// TODO(chron): Consider changing this back to track ShouldSyncAgain
// Only notify peers if a commit has occurred and change the bookmark model.
if (event.last_session && event.last_session->items_committed()) {
notification_pending_ = true;
@@ -1395,11 +1395,11 @@ void SyncManager::SyncInternal::HandleSyncerEvent(const SyncerEvent& event) {
observer_->OnSyncCycleCompleted();
}
- // TODO(chron): Consider changing this back to track ShouldSyncAgain
+ // TODO(chron): Consider changing this back to track HasMoreToSync
// Only notify peers if a commit has occurred and change the bookmark model.
if (event.last_session && event.last_session->items_committed()) {